@@ -1,5 +1,5 @@
 package Form::Factory::Feature::Role::Control;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 
 use Moose::Role;
@@ -12,12 +12,12 @@ Form::Factory::Feature::Role::Control - Form features tied to particular control
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
   package MyApp::Feature::Control::Color;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 
   use Moose;
@@ -52,7 +52,7 @@ our $VERSION = '0.009';
   }
 
   package Form::Factory::Feature::Control::Custom::Color;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 
   sub register_implementation { 'MyApp::Feature::Control::Color' }
@@ -60,7 +60,7 @@ our $VERSION = '0.009';
 And then used in an action via:
 
   package MyApp::Action::Foo;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 
   use Form::Factory::Processor;
@@ -104,6 +104,24 @@ has control => (
     },
 );
 
+=head1 ROLE METHODS
+
+=head2 check_control
+
+All features implementing this role must implement a C<check_control> method. This method is called when the L</control> attribute is initialized during construction. It should be defined like this:
+
+  sub check_control {
+      my ($self, $control) = @_;
+
+      # do something...
+  }
+
+Here C<$self> is the feature object. Be careful when using this, though, since this object is not fully constructed.
+
+The C<$control> argument is the control this feature is being attached to. You are expected to verify that your feature is compatible with the control given.
+
+The return value of this method is ignored. If the control is incompatible with your feature, your feature should die with a message explaining the problem.
+
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
